"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addSearchCLI = exports.checkTemplate = void 0;
const commander_1 = require("commander");
const myst_cli_utils_1 = require("myst-cli-utils");
const chalk_1 = __importDefault(require("chalk"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const __1 = __importStar(require(".."));
function fetchAuthor(session, id) {
    return __awaiter(this, void 0, void 0, function* () {
        const url = id.replace('https://openalex.org', 'https://api.openalex.org');
        session.log.debug(`Fetching infor from ${url}`);
        const resp = yield (0, node_fetch_1.default)(url);
        const data = (yield resp.json());
        return data;
    });
}
function checkTemplate(session, name) {
    return __awaiter(this, void 0, void 0, function* () {
        const url = `https://api.openalex.org/autocomplete/authors?q=${name}`;
        session.log.debug(`Fetching query from ${url}`);
        const resp = yield (0, node_fetch_1.default)(url);
        const data = (yield resp.json());
        session.log.debug(JSON.stringify(data, null, 2));
        const relevant = data.results.filter(({ external_id }) => external_id === null || external_id === void 0 ? void 0 : external_id.includes(__1.ORCID_URL));
        if (relevant.length === 0) {
            session.log.warn(`Did not find any results for query "${name}".`);
            return;
        }
        const authors = yield Promise.all(relevant.map((r) => __awaiter(this, void 0, void 0, function* () {
            const author = yield fetchAuthor(session, r.id);
            return { author, query: r };
        })));
        session.log.info(chalk_1.default.dim(`Found ${authors.length} result${authors.length > 1 ? 's' : ''} for "${name}" with an ORCID:\n`));
        authors.forEach((result) => {
            var _a, _b;
            session.log.info(`${chalk_1.default.green.bold(result.author.display_name)}`);
            session.log.info(`${chalk_1.default.blue.bold(__1.default.normalize(result.author.orcid))}`);
            session.log.info(`  Hint: ${chalk_1.default.dim(result.query.hint)}`);
            session.log.info(`  Last Institution: ${chalk_1.default.dim((_b = (_a = result.author.last_known_institution) === null || _a === void 0 ? void 0 : _a.display_name) !== null && _b !== void 0 ? _b : 'Unknown')}`);
            session.log.info(`  Concepts: ${chalk_1.default.dim(result.author.x_concepts
                .map((c) => c.display_name)
                .slice(0, 10)
                .join(', '))}`);
        });
    });
}
exports.checkTemplate = checkTemplate;
function makeSearchCLI(program) {
    const command = new commander_1.Command('search')
        .description('Check that a template passes validation')
        .argument('<name>', 'Path to the template directory')
        .action((0, myst_cli_utils_1.clirun)(checkTemplate, { program, getSession: myst_cli_utils_1.getSession }));
    return command;
}
function addSearchCLI(program) {
    program.addCommand(makeSearchCLI(program));
}
exports.addSearchCLI = addSearchCLI;
